.. toctree::
   :hidden:

   Home page <self>
   Installation and Usage <misc/installation_usage>
   Examples <examples/examples>
   API reference <_autosummary/sup3r>
   CLI reference <_cli/cli>

#################
Welcome to Sup3r!
#################

.. include:: ../../README.rst
   :start-after: inclusion-intro
